/**
 * @description Wrap表单配置信息
 */
export default function (wrap, subtype) {
  let appType = sessionStorage.getItem('appType')
  let roleList = sessionStorage.getItem('sysRoles')

  if (roleList) {
    try {
      roleList = JSON.parse(roleList)
    } catch (e) {
      roleList = []
    }
  } else {
    roleList = []
  }

  const cardWrapForm = [
    {
      type: 'text',
      field: 'title',
      label: '标题',
      initval: wrap.title || '',
      required: false
    },
    {
      type: 'text',
      field: 'name',
      label: '组件名称',
      initval: wrap.name || '',
      tooltip: '用于组件间的区分。',
      required: true
    },
    {
      type: 'number',
      field: 'width',
      label: '宽度',
      initval: wrap.width || 24,
      tooltip: '栅格布局，每行等分为24列。',
      min: 1,
      max: 24,
      precision: 0,
      required: true
    },
    {
      type: 'radio',
      field: 'datatype',
      label: '数据来源',
      initval: wrap.datatype || 'dynamic',
      tooltip: '选择静态值，无需配置数据源。',
      required: false,
      options: [
        {value: 'dynamic', label: '动态'},
        {value: 'static', label: '静态'},
      ],
      controlFields: [
        {field: 'empty', values: ['dynamic']},
      ],
      forbid: subtype !== 'propcard'
    },
    {
      type: 'radio',
      field: 'display',
      label: '显示模式',
      initval: wrap.display || 'normal',
      required: false,
      options: [
        {value: 'normal', label: '正常'},
        {value: 'modal', label: '弹窗'},
      ],
      controlFields: [
        {field: 'modalWidth', values: ['modal']},
        {field: 'modalContent', values: ['modal']},
        {field: 'code', values: ['modal']},
      ]
    },
    {
      type: 'radio',
      field: 'modalContent',
      label: '弹窗内容',
      initval: wrap.modalContent || 'message',
      required: false,
      options: [
        {value: 'message', label: '消息提醒'},
        {value: 'update', label: '系统更新'},
      ]
    },
    {
      type: 'styleInput',
      field: 'height',
      label: '组件高度',
      initval: wrap.height || '',
      required: true,
      options: ['px', 'vh']
    },
    {
      type: 'styleInput',
      field: 'modalWidth',
      label: '弹窗宽度',
      initval: wrap.modalWidth || '300px',
      required: true,
      options: ['px', 'vw'],
      forbid: appType === 'mob'
    },
    {
      type: 'text',
      field: 'code',
      label: '消息编码',
      initval: wrap.code || '',
      tooltip: '用于记录消息是否已读的标识，如果不同页面中存在相同消息，可指定固定值。',
      required: false,
      rules: [{
        pattern: /^[0-9a-zA-Z_]*$/ig,
        message: '只允许包含数字、字母以及_。'
      }]
    },
    {
      type: 'radio',
      field: 'autoplay',
      label: '自动切换',
      initval: wrap.autoplay || 'false',
      required: false,
      options: [
        {value: 'false', label: '否'},
        {value: 'true', label: '是'}
      ],
      controlFields: [
        {field: 'speed', values: ['true']}
      ]
    },
    {
      type: 'number',
      field: 'speed',
      label: '时间间隔',
      initval: wrap.speed || 3,
      tooltip: '默认为3秒',
      min: 1,
      max: 100,
      precision: 0,
      required: false
    },
    {
      type: 'radio',
      field: 'dots',
      label: '指示点',
      initval: wrap.dots || 'true',
      required: false,
      options: [
        {value: 'true', label: '显示'},
        {value: 'false', label: '隐藏'},
      ]
    },
    {
      type: 'radio',
      field: 'vertical',
      label: '垂直显示',
      initval: wrap.vertical || 'false',
      required: false,
      options: [
        {value: 'true', label: '是'},
        {value: 'false', label: '否'},
      ],
      forbid: appType !== 'mob'
    },
    {
      type: 'radio',
      field: 'dotPosition',
      label: '指示点位置',
      initval: wrap.dotPosition || 'bottom',
      required: false,
      options: [
        {value: 'top', label: '上'},
        {value: 'bottom', label: '下'},
        {value: 'left', label: '左'},
        {value: 'right', label: '右'},
      ],
      forbid: appType === 'mob'
    },
    {
      type: 'radio',
      field: 'effect',
      label: '动画效果',
      initval: wrap.effect || 'scrollx',
      required: false,
      options: [
        {value: 'scrollx', label: '切换'},
        {value: 'fade', label: '渐显'},
      ],
      forbid: appType === 'mob'
    },
    {
      type: 'radio',
      field: 'empty',
      label: '空值隐藏',
      initval: wrap.empty || 'show',
      tooltip: '当查询数据为空时，隐藏该组件。',
      required: false,
      skip: true,
      options: [
        {value: 'show', label: '否'},
        {value: 'hidden', label: '是'},
      ],
    },
    {
      type: 'radio',
      field: 'permission',
      label: '权限验证',
      initval: wrap.permission || 'false',
      required: false,
      options: [
        {value: 'true', label: '启用'},
        {value: 'false', label: '禁用'},
      ],
      forbid: !appType || sessionStorage.getItem('editMenuType') === 'popview'
    },
    {
      type: 'multiselect',
      field: 'blacklist',
      label: '黑名单',
      initval: wrap.blacklist || [],
      required: false,
      options: roleList,
      forbid: !!appType
    },
  ]

  return cardWrapForm
} 